@@ -16,35 +16,34 @@ import functools
 import logging
 import numbers
 import re
-import types
+import six
+import strict_rfc3339
 
-from connexion.utils import parse_datetime
 from connexion.problem import problem
+from connexion.utils import validate_date
 
-logger = logging.getLogger('connexion.decorators.parameters')
+logger = logging.getLogger('connexion.decorators.validation')
 
 
 # https://github.com/swagger-api/swagger-spec/blob/master/versions/2.0.md#data-types
 TYPE_MAP = {'integer': int,
             'number': numbers.Number,
-            'string': str,
+            'string': six.string_types[0],
             'boolean': bool,
             'array': list,
             'object': dict}  # map of swagger types to python types
 
 
-FORMAT_MAP = {('string', 'date-time'): parse_datetime}
+FORMAT_MAP = {('string', 'date-time'): strict_rfc3339.validate_rfc3339,
+              ('string', 'date'): validate_date}
 
 
 def validate_format(schema, data):
     schema_type = schema.get('type')
     schema_format = schema.get('format')
     func = FORMAT_MAP.get((schema_type, schema_format))
-    if func:
-        try:
-            func(data)
-        except:
-            return "Invalid value, expected {} in '{}' format".format(schema_type, schema_format)
+    if func and not func(data):
+        return "Invalid value, expected {} in '{}' format".format(schema_type, schema_format)
 
 
 def validate_pattern(schema, data):
@@ -66,14 +65,40 @@ def validate_maximum(schema, data):
         return 'Invalid value, must be at most {}'.format(maximum)
 
 
-VALIDATORS = [validate_format, validate_pattern, validate_minimum, validate_maximum]
+def validate_min_length(schema, data):
+    minimum = schema.get('minLength')
+    if minimum is not None and len(data) < minimum:
+        return 'Length must be at least {}'.format(minimum)
+
+
+def validate_max_length(schema, data):
+    maximum = schema.get('maxLength')
+    if maximum is not None and len(data) > maximum:
+        return 'Length must be at most {}'.format(maximum)
+
+
+def validate_enum(schema, data):
+    enum_values = schema.get('enum')
+    if enum_values is not None and data not in enum_values:
+        return 'Enum value must be one of {}'.format(enum_values)
+
+
+VALIDATORS = [validate_format, validate_pattern,
+              validate_minimum, validate_maximum,
+              validate_min_length, validate_max_length,
+              validate_enum]
 
 
 class RequestBodyValidator:
     def __init__(self, schema):
         self.schema = schema
 
-    def __call__(self, function: types.FunctionType) -> types.FunctionType:
+    def __call__(self, function):
+        """
+        :type function: types.FunctionType
+        :rtype: types.FunctionType
+        """
+
         @functools.wraps(function)
         def wrapper(*args, **kwargs):
             data = flask.request.json
@@ -88,7 +113,11 @@ class RequestBodyValidator:
 
         return wrapper
 
-    def validate_schema(self, data, schema) -> flask.Response:
+    def validate_schema(self, data, schema):
+        """
+        :type schema: dict
+        :rtype: flask.Response | None
+        """
         schema_type = schema.get('type')
         log_extra = {'url': flask.request.url, 'schema_type': schema_type}
 
